library(seqinr)
library(stats)
library(ape)

#################
#Install packages
#################
#Run if you need to install these packages

#install.packages("seqinr")
#install.packages("ape")


##############
#Load the data
##############
files.human <- list.files("PDZLigands/human", pattern="*.fa", full.names=TRUE)
files.worm <- list.files("PDZLigands/worm", pattern="*.fa", full.names=TRUE)


##################
#Get the PDZ names
##################
PDZ.human <- unlist(lapply(files.human, function(x){strsplit(  strsplit(x, "/")[[1]][length(strsplit(x, "/")[[1]])], ".", fixed=T )[[1]][1] }))
PDZ.worm <- unlist(lapply(files.worm, function(x){  y <- strsplit(x, "/")[[1]][length(strsplit(x, "/")[[1]])]; paste( strsplit(y, ".", fixed=T )[[1]][1], strsplit(y, ".", fixed=T )[[1]][2], sep=".") }))
PDZ.all <- c(PDZ.human, PDZ.worm)

PDZ.org <- c(rep("H", length(PDZ.human)), rep("W", length(PDZ.worm)))
names(PDZ.org) <- PDZ.all


####################
#Get the PDZ classes
####################
PDZ.class <- read.table("PDZclass.txt", skip=1)
class2 <- as.numeric(PDZ.class[,2])
names(class2) <- PDZ.all
class7 <- as.numeric(PDZ.class[,3])
names(class7) <- PDZ.all
class16 <- as.character(PDZ.class[,4])
names(class16) <- PDZ.all


#########################
#Load the background freq
#########################
b <- read.table("phageLibraryNNKTheoreticalCodonBias.txt")
bg.fr <- b[,2]

map <- c(1:21, 21)
names(map) <- c("A", "C", "D", "E", "F", "G", "H", "I", "K", "L", "M", "N", "P", "Q", "R", "S", "T", "V", "W", "Y", "X", "-")


################################
#Get the sequence of the ligands
################################
loadFile <- function(x){
  f <- read.fasta(file=x, as.string = TRUE, seqtype = "AA")
  nm <- names(f)
  seq <- unlist(lapply(nm, function(x){f[[x]][1]}))
  return(seq)
}

seq.human <- lapply(files.human, loadFile)
seq.worm <- lapply(files.worm, loadFile)
seq.all <- c(seq.human, seq.worm)
names(seq.all) <- PDZ.all


############################
#Load the sequence alignment
############################
#f <- read.fasta(file="PDZ_SMART_MUSCLE_sub.fa", as.string = TRUE, seqtype = "AA")
#f <- read.fasta(file="PDZ_SMART_CLUSTAL_sub.fa", as.string = TRUE, seqtype = "AA")
f <- read.fasta(file="PDZ_phage_MUSCLE.fa", as.string = TRUE, seqtype = "AA")

PDZ.seq <- unlist(lapply(PDZ.all, function(x){f[[x]][1]}))
bs <- which(unlist(strsplit(f[[1]][1], ""))=="B") 

bs.seq <- unlist(lapply(PDZ.seq, function(x){ paste(unlist(strsplit(x, ""))[bs], sep="", collapse="") }))
names(bs.seq) <- PDZ.all



